var gulp    = require('gulp'),
concat      = require('gulp-concat'),
sass        = require('gulp-sass'),
// ngAnnotate  = require('gulp-ng-annotate'),
sourcemaps  = require('gulp-sourcemaps'),
minify      = require('gulp-minify');
terser      = require('gulp-terser');
rename      = require("gulp-rename");

var sassPaths=[];

var admin_script_files=[
    'js/components/jquery.jsonview.js',
    'js/admin/*.js'
];

var client_script_files=[
    'js/components/jquery.magnific-popup.js',
    'js/components/noui-range.js',
    'js/components/slick.js',
    'js/client/rentpress-global.js',
    'js/client/media-optimization.js',
    'js/client/shortcode-units-table.js',
    'js/client/single-fp.js'
];

var floorplan_archive_template_script_files=[
    // 'js/components/noui-range.js',
    'js/template/archive-floorplans-basic.js'
];

var property_archive_template_script_files = [
    'js/template/archive-properties-basic.js'
];

var advanced_property_archive_template_script_files = [
    'js/template/archive-properties-advanced.js'
];

// ADMIN TASKS
gulp.task('admin-sass', function() {
    return gulp.src('scss/admin-side.scss')
        .pipe(sourcemaps.init())
        .pipe(sass({
            includePaths: sassPaths,
            outputStyle: 'compressed'
        })
        .on('error', sass.logError))
        .pipe(sourcemaps.write())
        .pipe(gulp.dest('build/css'));
});

gulp.task('admin-js', function() {  
    return gulp.src(admin_script_files)
        .pipe(sourcemaps.init())
        .pipe(concat('admin-side.js'))
        .pipe(sourcemaps.write())
        .pipe(gulp.dest('build/js'));
});

gulp.task('admin-minify-js', function() {
    return gulp.src(admin_script_files)
        .pipe(concat('admin-side.noMaps.js'))
        .pipe(minify())
        .pipe(gulp.dest('build/js'));
});

// CLIENT TASKS
gulp.task('client-sass', function() {
    return gulp.src('scss/client-side.scss')
        .pipe(sourcemaps.init())
        .pipe(sass({
            includePaths: sassPaths,
            outputStyle: 'compressed'
        })
        .on('error', sass.logError))
        .pipe(sourcemaps.write())
        .pipe(gulp.dest('build/css'));
});

gulp.task('client-js', function() {
    return gulp.src(client_script_files)
        .pipe(sourcemaps.init())
        .pipe(concat('client-side.js'))
        .pipe(sourcemaps.write())
        .pipe(gulp.dest('build/js'));
});

gulp.task('client-minify-js', function() {
    return gulp.src(client_script_files)
        .pipe(concat('client-side.noMaps.js'))
        .pipe(terser())
        .pipe(gulp.dest('build/js'));
});

gulp.task('fp-template-minify-js', function() {
    return gulp.src(floorplan_archive_template_script_files)
        .pipe(concat('archive-floorplans-basic.js'))
        .pipe(rename('archive-floorplans-basic.min.js'))
        .pipe(terser())
        .pipe(gulp.dest('build/js/templates'));
});

gulp.task('prop-template-minify-js', function() {
    return gulp.src(property_archive_template_script_files)
        .pipe(concat('archive-properties-basic.js'))
        .pipe(rename('archive-properties-basic.min.js'))
        .pipe(terser())
        .pipe(gulp.dest('build/js/templates'));
});

gulp.task('advanced-prop-template-minify-js', function() {
    return gulp.src(advanced_property_archive_template_script_files)
        .pipe(concat('archive-properties-advanced.js'))
        .pipe(rename('archive-properties-advanced.min.js'))
        .pipe(terser())
        .pipe(gulp.dest('build/js/templates'));
});

// COMBINDING TASKS
gulp.task('render-admin', ['admin-sass', 'admin-js', 'admin-minify-js']);

gulp.task('render-client', ['client-sass', 'client-js', 'client-minify-js']);

gulp.task('render-template', ['client-sass', 'fp-template-minify-js', 'prop-template-minify-js']);

gulp.task('render-template', ['client-sass', 'fp-template-minify-js', 'prop-template-minify-js', 'advanced-prop-template-minify-js']);

// THE DEFAULTS
gulp.task('watch', function() {

    gulp.watch(
        [
            'scss/*', 'scss/**/*',
            'js/*', 'js/**/*'
            
        ],
        ['render-admin', 'render-client', 'render-template']
    );

});

gulp.task('default', ['render-admin', 'render-client', 'render-template', 'watch']);